import type { FaSize, IconName, IconStyle } from '../icon';
import type { FoundationRoute } from './router';
/**
 * FoundationRouteNavItem
 * @remarks
 * Many of the properties are dynamically assigned if not set explicitly.
 * @beta
 */
export type FoundationRouteNavItem = {
    title: string;
    icon?: {
        name: IconName;
        size?: FaSize;
        variant?: IconStyle;
    };
    /**
     * @remarks
     * Defaults to 'header'.
     */
    navId?: string;
    /**
     * @remarks
     * Lower numbers move items earlier in navs. If not explicitly assigned, this value defaults to the route mapping
     * order and has automatic index padding applied which defaults to 10. Results in, 10, 20, 30...
     */
    placementIndex?: number;
    /**
     * @remarks
     * Defaults to the route details, but can be set to target elsewhere.
     */
    routePath?: string;
    routeName?: string;
};
/**
 * @beta
 */
export type NavItemPredicate = (item: FoundationRouteNavItem) => boolean;
/**
 * @beta
 */
export declare const defaultNavItemPredicate: NavItemPredicate;
/**
 * @beta
 */
export declare const defaultPlacementIndexPadding = 10;
/**
 * Get navigation items from routes.
 * @beta
 */
export declare function getNavItems(routes: FoundationRoute[], predicate?: NavItemPredicate, placementIndexPadding?: number): FoundationRouteNavItem[];
//# sourceMappingURL=navItems.d.ts.map