import { FoundationAnalytics } from '@genesislcap/foundation-comms';
import { User } from '@genesislcap/foundation-user';
import { Constructable, FASTElement } from '@microsoft/fast-element';
import { Container } from '@microsoft/fast-foundation';
import { MappableRouteDefinition, RouteCollection, RouterConfiguration, RouterElement } from '@microsoft/fast-router';
import type { FoundationRouteNavItem, NavItemPredicate } from './navItems';
declare const FoundationRouter_base: new () => FASTElement & RouterElement;
/**
 * @beta
 * @privateRemarks
 * Created to patch an issue and act as a placeholder to improve the api ahead of upgrading to the latest. Depending on
 * how much we build on this, we may want to promote it to its own package.
 */
export declare class FoundationRouter extends FoundationRouter_base {
    config: FoundationRouterConfiguration | null;
    connectedCallback(): void;
}
/**
 * @beta
 */
export type FoundationRoute<TSettings = any> = MappableRouteDefinition<TSettings> & {
    navItems?: FoundationRouteNavItem[];
};
/**
 * @beta
 */
export declare class FoundationRouteCollection<TSettings = any> extends RouteCollection<TSettings> {
    definitions: FoundationRoute<TSettings>[];
    map(...routes: FoundationRoute<TSettings>[]): void;
}
/**
 * @beta
 */
export declare abstract class FoundationRouterConfiguration<TSettings = any> extends RouterConfiguration<TSettings> {
    protected container: Container;
    protected analytics: FoundationAnalytics;
    user: User;
    readonly routes: FoundationRouteCollection<TSettings>;
    /**
     * @remarks
     * Get navigation items from the route definitions.
     */
    getNavItems(predicate?: NavItemPredicate): FoundationRouteNavItem[];
    /**
     * @remarks
     * Applies the analytics service to the navigate phase.
     */
    configureAnalytics(): void;
    construct<T>(Type: Constructable<T>): T;
}
export {};
//# sourceMappingURL=router.d.ts.map