import { __awaiter, __decorate } from "tslib";
import { observable } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { logger } from '../utils';
import { foundationBannerStyles as styles } from './banner.styles';
import { foundationBannerTemplate as template } from './banner.template';
export const foundationBannerShadowOptions = {
    mode: 'open',
    delegatesFocus: true,
};
/**
 * @tagname %%prefix%%-banner
 */
export class Banner extends FoundationElement {
    constructor() {
        super(...arguments);
        this.dismissAnimation = '';
    }
    connectedCallback() {
        super.connectedCallback();
    }
    /**
     * Dismiss the Banner from display.
     */
    dismiss() {
        this.dismissAnimation = 'banner-delete';
        return new Promise((resolve) => {
            this.banner.onanimationend = () => {
                this.remove();
                resolve();
            };
        });
    }
    /**
     * Dismiss the Banner (NotificationStructure) from display.
     */
    dismissNotification() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.dismiss();
                this.remove();
            }
            catch (e) {
                logger.error(e);
            }
        });
    }
}
__decorate([
    observable
], Banner.prototype, "dismissAnimation", void 0);
__decorate([
    observable
], Banner.prototype, "notification", void 0);
/**
 * The Foundation Banner
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-banner\>
 */
export const foundationBanner = Banner.compose({
    baseName: 'banner',
    styles,
    template,
    shadowOptions: foundationBannerShadowOptions,
});
