import { __decorate } from "tslib";
import { DesignSystemProvider as FASTDesignSystemProvider, } from '@microsoft/fast-components';
import { attr, html } from '@microsoft/fast-element';
import * as tokens from '../_config/tokens';
import { fuiCardFillColor, fuiCardForegroundColor } from '../_config/tokens/custom';
import * as values from '../_config/values';
import { designSystemProviderStyles } from './design-system-provider.styles';
import { designToken, provideTokens, swatchConverter } from './design-system-provider.utils';
/**
 * The Foundation Design System Provider
 * @public
 * @tagname %%prefix%%-design-system-provider
 */
export class FoundationDesignSystemProvider extends FASTDesignSystemProvider {
    constructor() {
        super();
        provideTokens(tokens, values, this);
    }
}
__decorate([
    attr({
        attribute: 'card-fill-color',
        converter: swatchConverter,
    }),
    designToken(fuiCardFillColor)
], FoundationDesignSystemProvider.prototype, "cardFillColor", void 0);
__decorate([
    attr({
        attribute: 'card-foreground-color',
        converter: swatchConverter,
    }),
    designToken(fuiCardForegroundColor)
], FoundationDesignSystemProvider.prototype, "cardForegroundColor", void 0);
/**
 * The Foundation Design System Provider composed element
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-design-system-provider\>
 */
export const foundationDesignSystemProvider = FoundationDesignSystemProvider.compose({
    baseName: 'design-system-provider',
    template: html `
    <slot></slot>
  `,
    styles: designSystemProviderStyles,
});
