import { css } from '@microsoft/fast-element';
import { display, forcedColorsStylesheetBehavior, } from '@microsoft/fast-foundation';
import { SystemColors } from '@microsoft/fast-web-utilities';
import { mixinFoundationFontFamily } from '../_config/styles';
import { fuiFillColor } from '../_config/tokens';
const baseStyles = css `
  ${display('flex')}
  :host {
    flex: 1;
  }
`;
const backgroundStyles = css `
  :host {
    background-color: ${fuiFillColor};
  }
`.withBehaviors(forcedColorsStylesheetBehavior(css `
    :host {
      background-color: ${SystemColors.ButtonFace};
      box-shadow: 0 0 0 1px ${SystemColors.CanvasText};
      color: ${SystemColors.ButtonText};
    }
  `));
const getHeaderForContext = (context, headingLevel) => css `
  ${context.name} ${'h' + headingLevel} {
    margin: 0;
  }
`;
const typography = (context) => css `
  ${getHeaderForContext(context, '1')}
  ${getHeaderForContext(context, '2')}
  ${getHeaderForContext(context, '3')}
  ${getHeaderForContext(context, '4')}
  ${getHeaderForContext(context, '5')}
  ${getHeaderForContext(context, '6')}
`;
export const designSystemProviderStyles = (context) => {
    const contextualizedTypography = typography(context);
    // Document-level but contextualized overrides (h1, h2, span, etc)
    contextualizedTypography.addStylesTo(document);
    return css `
    ${baseStyles}
    ${backgroundStyles}
    ${contextualizedTypography}
    :host * {
      ${mixinFoundationFontFamily()}
    }
  `;
};
