import { __decorate } from "tslib";
import { attr, html, css } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { createPopper } from '@popperjs/core';
export const jsonConverter = {
    toView(value) {
        return JSON.stringify(value);
    },
    fromView(value) {
        if (value === null || value === undefined)
            return value;
        return JSON.parse(value);
    },
};
/**
 * @tagname %%prefix%%-popper
 */
export class Popper extends FoundationElement {
    constructor() {
        super(...arguments);
        this.show = false;
        this.event = 'click';
        this.placement = 'bottom';
        this.flip = false;
    }
    selectorChanged(oldValue, newValue) {
        if (newValue === oldValue)
            return;
        if (this.popper)
            this.popper.destroy();
        if (this.target) {
            this.target.removeEventListener(this.event, this.toggle.bind(this));
        }
        this.target = this.getRootNode().querySelector(this.selector);
        this.target.addEventListener(this.event, this.toggle.bind(this));
        this.popper = createPopper(this.target, this, this.buildOptions());
    }
    placementChanged() {
        if (this.popper)
            this.popper.setOptions(this.buildOptions());
    }
    offsetChanged() {
        if (this.popper)
            this.popper.setOptions(this.buildOptions());
    }
    flipChanged() {
        if (this.popper)
            this.popper.setOptions(this.buildOptions());
    }
    buildOptions() {
        const options = {
            placement: this.placement,
            modifiers: [
                {
                    name: 'offset',
                    options: {
                        offset: this.offset || [0, 0],
                    },
                },
                {
                    name: 'flip',
                    enabled: this.flip,
                },
            ],
        };
        return options;
    }
    toggle() {
        this.show = !this.show;
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        if (this.popper) {
            this.popper.destroy();
            this.popper = null;
        }
    }
}
__decorate([
    attr
], Popper.prototype, "selector", void 0);
__decorate([
    attr({ mode: 'boolean' })
], Popper.prototype, "show", void 0);
__decorate([
    attr
], Popper.prototype, "event", void 0);
__decorate([
    attr
], Popper.prototype, "placement", void 0);
__decorate([
    attr({ converter: jsonConverter })
], Popper.prototype, "offset", void 0);
__decorate([
    attr({ mode: 'boolean' })
], Popper.prototype, "flip", void 0);
const styles = css `
  :host {
    display: none;
    inset: unset !important;
    transform: unset !important;
  }

  :host([show]) {
    display: block;
  }
`;
const template = html `
  <template>
    <slot></slot>
  </template>
`;
/**
 * The Foundation Popper
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-popper\>
 */
export const foundationPopper = Popper.compose({
    baseName: 'popper',
    styles,
    template,
});
