/**
 * @beta
 */
export const defaultNavItemPredicate = (item) => !item.navId || item.navId === 'header';
/**
 * @beta
 */
export const defaultPlacementIndexPadding = 10;
/**
 * Get navigation items from routes.
 * @beta
 */
export function getNavItems(routes, predicate = defaultNavItemPredicate, placementIndexPadding = defaultPlacementIndexPadding) {
    const items = [];
    routes
        .filter((route) => route.navItems && route.navItems.some(predicate))
        .forEach((route, routeIndex) => {
        route.navItems
            .filter(predicate)
            .map((item, navItemIndex) => {
            var _a, _b, _c, _d;
            /**
             * Best guess placementIndex
             */
            const placementIndex = (_a = item.placementIndex) !== null && _a !== void 0 ? _a : routeIndex * placementIndexPadding + navItemIndex;
            /**
             * Map metadata not explicitly set
             */
            return Object.assign(Object.assign({}, item), { navId: (_b = item.navId) !== null && _b !== void 0 ? _b : 'header', placementIndex, routePath: (_c = item.routePath) !== null && _c !== void 0 ? _c : route.path, routeName: (_d = item.routeName) !== null && _d !== void 0 ? _d : route.name });
        })
            .forEach((item) => items.push(item));
    });
    /**
     * Returned sorted items based on placementIndex
     */
    return items.sort((a, b) => a.placementIndex - b.placementIndex);
}
