import { __decorate } from "tslib";
import { Combobox } from '@microsoft/fast-components';
import { attr } from '@microsoft/fast-element';
import { foundationSearchBarComboboxStyles } from './search-bar-combobox.styles';
import { foundationSearchBarComboboxTemplate } from './search-bar-combobox.template';
import { COMBO_INPUT_MIN_LENGTH } from './search-bar.types';
/**
 * @tagname %%prefix%%-search-bar-combobox
 */
export class SearchBarCombobox extends Combobox {
    constructor() {
        super(...arguments);
        this.minlength = COMBO_INPUT_MIN_LENGTH;
        this.previousLength = -1;
        this.changeListener = (e) => {
            this.previousLength = 0;
        };
    }
    connectedCallback() {
        super.connectedCallback();
        this.addEventListener('change', this.changeListener);
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        this.removeEventListener('change', this.changeListener);
    }
    clickHandler(e) {
        if (this.disabled) {
            return;
        }
        if (this.open) {
            const captured = e.target.closest(`option,[role=option]`);
            if (!captured || captured.disabled) {
                return;
            }
            this.selectedOptions = [captured];
            this.control.value = captured.text;
            this.value = this.control.value;
            this.$emit('change');
        }
        this.control.focus();
    }
    keyupHandler(e) {
        const key = e.key;
        switch (key) {
            case 'Backspace':
            case 'Delete': {
                if (this.previousLength < 0) {
                    this.$emit('inputdeleted');
                }
                else {
                    this.previousLength = this.previousLength - 1;
                }
                break;
            }
            case 'Enter': {
                if (this.open && this.selectedIndex !== -1) {
                    const firstOption = this.slottedOptions[0];
                    this.selectedOptions = [firstOption];
                    this.control.value = firstOption.text;
                    this.value = this.control.value;
                    this.$emit('change');
                }
            }
        }
        super.keyupHandler(e);
    }
    keydownHandler(e) {
        const key = e.key;
        switch (key) {
            case 'ArrowUp':
            case 'ArrowDown': {
                if (this.control.value.length < this.minlength) {
                    return;
                }
                else {
                    return super.keydownHandler(e);
                }
            }
            case 'Enter': {
                if (this.selectedIndex === -1) {
                    return false;
                }
                return super.keydownHandler(e);
            }
            case 'Tab': {
                if (!this.open) {
                    return true;
                }
                if (e.shiftKey) {
                    this.selectPreviousOption();
                }
                else {
                    this.selectNextOption();
                }
                break;
            }
            default:
                return super.keydownHandler(e);
        }
    }
    inputHandler(e) {
        if (this.control.value.length >= this.minlength) {
            this.open = true;
        }
        else {
            e.stopImmediatePropagation();
            this.open = false;
        }
        this.value = this.control.value;
        this.previousLength = this.control.value.length;
    }
    openChanged() {
        if (this.open) {
            this.ariaControls = this.listboxId;
            this.ariaExpanded = 'true';
            this.setPositioning();
            this.focusAndScrollOptionIntoView();
            return;
        }
        this.ariaControls = '';
        this.ariaExpanded = 'false';
    }
}
__decorate([
    attr
], SearchBarCombobox.prototype, "minlength", void 0);
export const foundationSearchBarComboboxShadowOptions = {
    delegatesFocus: true,
    mode: 'open',
};
export const defaultSearchBarComboboxConfig = {};
/**
 * The Foundation Search Bar Combobox
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-search-bar-combobox\>
 */
export const foundationSearchBarCombobox = SearchBarCombobox.compose(Object.assign({ baseName: 'search-bar-combobox', template: foundationSearchBarComboboxTemplate, styles: foundationSearchBarComboboxStyles, shadowOptions: foundationSearchBarComboboxShadowOptions }, defaultSearchBarComboboxConfig));
