import { html, ref, repeat, slotted } from '@microsoft/fast-element';
import { whitespaceFilter } from '@microsoft/fast-foundation';
import { classNames } from '@microsoft/fast-web-utilities';
import { getPrefix } from '../utils';
export const crossIcon = (slot = 'start') => `
<svg xmlns:xlink="http://www.w3.org/1999/xlink" xmlns="http://www.w3.org/2000/svg" version="1.1" width="10px" height="10px">
  <g transform="matrix(1 0 0 1 -256 -14 )">
    <path class="cross-icon" fill="white" d="M 9.9265625 8.865937499999998  L 6.060625000000001 5  L 9.265625 1.795  L 9.9265625 1.1340624999999993  C 10.0240625 1.0365624999999996  10.0240625 0.8781249999999996  9.9265625 0.7806249999999992  L 9.219375 0.07343749999999982  C 9.121875 -0.024062500000000542  8.9634375 -0.024062500000000542  8.8659375 0.07343749999999982  L 5 3.9393750000000005  L 1.1340625 0.073125  C 1.0365625 -0.02437500000000037  0.8781250000000002 -0.02437500000000037  0.7806249999999999 0.073125  L 0.073125 0.7803125  C -0.024375000000000008 0.8778124999999998  -0.024375000000000008 1.0362499999999997  0.073125 1.13375  L 3.9393750000000005 5  L 0.073125 8.865937499999998  C -0.024375000000000008 8.9634375  -0.024375000000000008 9.121875  0.073125 9.219375000000001  L 0.7803125 9.9265625  C 0.8778125000000001 10.0240625  1.03625 10.0240625  1.13375 9.9265625  L 5 6.060625  L 8.205 9.265625  L 8.8659375 9.9265625  C 8.9634375 10.0240625  9.121875 10.0240625  9.219375 9.9265625  L 9.9265625 9.219375000000001  C 10.0240625 9.121875  10.0240625 8.9634375  9.9265625 8.865937499999998  Z " fill-rule="nonzero" fill="#c9c9c9" stroke="none" fill-opacity="0.8" transform="matrix(1 0 0 1 256 14 )"/>
  </g>
</svg>
`;
export const plusIcon = () => `
<svg xmlns="http://www.w3.org/2000/svg" fill="currentColor" width="30px" height="30px" class="bi bi-plus" viewBox="0 0 16 16">
  <path d="M8 4a.5.5 0 0 1 .5.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3A.5.5 0 0 1 8 4z"/>
</svg>`;
export const getPrefixedSearchBar = (prefix) => html `

  <label part="label" for="control" data-test-id="label" class=${(x) => { var _a; return classNames('label', ['label-hidden', !((_a = x.defaultSlottedNodes) === null || _a === void 0 ? void 0 : _a.length)]); }}
  >
    <slot
      ${slotted({
    property: 'defaultSlottedNodes',
    filter: whitespaceFilter,
})}
    ></slot>
  </label>

  <${prefix}-search-bar-combobox
    ${ref('combobox')}
    position="${(x) => x.position}"
    placeholder=${(x) => x.placeholder}
    disabled=${(x) => x.disabled}
    autocomplete="none"
    minlength=${(x) => x.minlength}
    @inputdeleted=${(x) => x.inputdeleted()}
    @change=${(x) => x.changeHandler()}
    @input=${(x) => x.inputHandler()}
    @paste=${(x, c) => x.pasteHandler(c.event)}
    class="search-bar-combobox ${(x) => (x.selectedOptions.length > 0 ? 'padding' : null)}"
    data-test-id="search-bar"
  >
    <div
      ${ref('selectedOptionsDiv')}
      slot="selectedOptions"
      class="selected-options ${(x) => x.selectedOptions.length > 0 ? 'selected-options-divider' : null}"
    >
      ${repeat((x) => x.selectedOptions, html `
          <${prefix}-button
            class="options-button"
            appearance=${(x, c) => c.parent.appearance}
            disabled=${(x, c) => c.parent.disabled}
            @click=${(x, c) => c.parent.unselectOption(x)}
          >
            ${(x) => x.label}
            <${prefix}-icon
              class="close-icon"
              slot="end"
              name="circle-xmark"
              variant="regular"
            ></${prefix}-icon>
          </${prefix}-button>
        `)}
    </div>
    ${repeat((x) => x.filteredOptions, html `
        <${prefix}-option
          value="${(x) => x.field}"
          :disabled=${(x, ctx) => !x.isEnabled(ctx.parent.searchTerm, ctx.parent.selectedOptions)}
        >
          ${(x, ctx) => x.label(ctx.parent.searchTerm)}
        </${prefix}-option>
      `)}
    <${prefix}-button
      class="search-clear-button"
      @click=${(x) => x.clearSearch()}
      id="search-clear-button"
      slot="end"
      data-test-id="clear-search"
    >
      <div class="svg-container">
        <svg
          xmlns="http://www.w3.org/2000/svg"
          fill="currentColor"
          width="26px"
          height="26px"
          class="bi bi-plus"
          viewBox="0 0 16 16"
        >
          <path
            d="M8 4a.5.5 0 0 1 .5.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3A.5.5 0 0 1 8 4z"
          />
        </svg>
      </div>
    </${prefix}-button>
  </${prefix}-search-bar-combobox>
  <${prefix}-tooltip class="tooltip" anchor="search-clear-button">
    Clear Search Terms
  </${prefix}-tooltip>
`;
export const foundationSearchBarTemplate = html `
  ${(x) => getPrefixedSearchBar(getPrefix(x))}
`;
